Module breadcrumb

Module breadcrumb 

Breadcrumb — a horizontal trail of navigable links.

All but the last item render as clickable links separated by a chevron; the final item is the muted “current page” and is not clickable. [show] returns the index of the item clicked this frame, if any.

if let Some(i) = sc::Breadcrumb::new()
    .item("Home")
    .item("Library")
    .current("Data structures")
    .show(ui)
{
    // navigate to crumb `i`
}

Structs

Breadcrumb