DirPosition

Enum DirPosition 

pub enum DirPosition<NodeIdType> {
    First,
    Last,
    After(NodeIdType),
    Before(NodeIdType),
}
A position inside a directory node.

When a source node is dragged this enum describes the position where the node should be dropped inside a directory node.

Variants



First

The source node should be inserted in the first position of the directory



Last

The source node should be inserted in the last position of the directory.



After(NodeIdType)

The source node should be inserted after the node with this node id.



Before(NodeIdType)

The source node should be inserted before the node with this node id.