IndentHintStyle

Enum IndentHintStyle 

pub enum IndentHintStyle {
    None,
    Line,
    Hook,
}
Style of the vertical line to show the indentation level.

Variants



None

No indent hint is shown.



Line

A single vertical line is show for the full height of the directory.

v Foo
│  Alice
│  v Bar
│  │ Bob
│  │  v Baz
│  │  │ Clair
│  │  │ Denis
│  Emil


Hook

A vertical line is show with horizontal hooks to the child nodes of the directory.

v Foo
├─ Alice
├─ v Bar
│  ├─ Bob
│  └─ v Baz
│     ├─ Clair
│     └─ Denis
└─ Emil