Enum RowLayout Copy item path Source pub enum RowLayout {
Compact,
CompactAlignedLabels,
AlignedIcons,
AlignedIconsAndLabels,
}Expand description How rows in the tree are laid out.
Each row in the tree is made up of three elements. A closer,
an icon and a label. The layout of these elements is controlled
by this value.
No icons are displayed.
Directories only show the closer and the label.
Leaves only show the label and allocate no additional space for a closer.
Labels between leaves and directories do not align.
The labels of leaves and directories are aligned.
Icons are displayed for leaves only.
The icons of leaves and directories are aligned.
If a leaf or directory does not show an icon, the label will fill the
space. Labels between leaves and directories can be misaligned.
The labels of leaves and directories are aligned.
If a leaf or directory does not show an icon, the label will not fill
the space.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Returns the “default value” for a type.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Checks if this value is equivalent to the given key.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.