TreeViewState

Struct TreeViewState 

pub struct TreeViewState<NodeIdType>
where NodeIdType: Eq + Hash,
{ /* private fields */ }
Represents the state of the tree view.

This holds which node is selected and the open/close state of the directories.

Implementations

Source

impl<NodeIdType> TreeViewState<NodeIdType>
where NodeIdType: NodeId + Send + Sync + 'static,

pub fn load(ui: &mut Ui, id: Id) -> Option<TreeViewState<NodeIdType>>

Load a TreeViewState from memory.

pub fn store(self, ui: &mut Ui, id: Id)

Store this TreeViewState to memory.

Source

impl<NodeIdType> TreeViewState<NodeIdType>
where NodeIdType: NodeId,

pub fn selected(&self) -> &Vec<NodeIdType>

Return the list of selected nodes

pub fn set_selected(&mut self, selected: Vec<NodeIdType>)

Set which nodes are selected in the tree

pub fn set_one_selected(&mut self, selected: NodeIdType)

Set a single node to be selected.

pub fn expand_parents_of(&mut self, _id: &NodeIdType)

Expand all parent nodes of the node with the given id.

pub fn expand_node(&mut self, _id: &NodeIdType)

Expand the node and all its parent nodes. Effectively this makes the node visible in the tree.

pub fn set_openness(&mut self, id: NodeIdType, open: bool)

Set the openness state of a node.

pub fn is_open(&self, id: &NodeIdType) -> Option<bool>

Get the open state of the node. If this node is unknown to the tree view this will return None. If the node is known to the tree view but still uses its default value this method will also return None.

pub fn parent_id_of(&self, _id: &NodeIdType) -> Option<&NodeIdType>

👎Deprecated:

The TreeViewState no longer carries this information. Refer to your own data source

Get the parent id of a node.