pub trait NodeId:
Clone
+ PartialEq
+ Eq
+ Hash { }Expand description
Identifies a node in the tree.
This is just a trait alias for the collection of necessary traits that a node id must implement.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".