pub enum IndentHintStyle {
None,
Line,
Hook,
}Expand description
Style of the vertical line to show the indentation level.
Variants
None
No indent hint is shown.
Line
A single vertical line is show for the full height of the directory.
v Foo
│ Alice
│ v Bar
│ │ Bob
│ │ v Baz
│ │ │ Clair
│ │ │ Denis
│ EmilHook
A vertical line is show with horizontal hooks to the child nodes of the directory.
v Foo
├─ Alice
├─ v Bar
│ ├─ Bob
│ └─ v Baz
│ ├─ Clair
│ └─ Denis
└─ EmilTrait Implementations
Sourceimpl Clone for IndentHintStyle
impl Clone for IndentHintStyle
Sourcefn clone(&self) -> IndentHintStyle
fn clone(&self) -> IndentHintStyle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndentHintStyle
impl Debug for IndentHintStyle
Sourceimpl Default for IndentHintStyle
impl Default for IndentHintStyle
Sourcefn default() -> IndentHintStyle
fn default() -> IndentHintStyle
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for IndentHintStyle
impl PartialEq for IndentHintStyle
Sourcefn eq(&self, other: &IndentHintStyle) -> bool
fn eq(&self, other: &IndentHintStyle) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for IndentHintStyle
impl Eq for IndentHintStyle
impl StructuralPartialEq for IndentHintStyle