NodeId

Trait NodeId 

pub trait NodeId:
    Clone
    + PartialEq
    + Eq
    + Hash { }
Identifies a node in the tree.

This is just a trait alias for the collection of necessary traits that a node id must implement.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> NodeId for T
where T: Clone + PartialEq + Eq + Hash,

Available on non-crate feature persistence only.